@@ -100,7 +100,9 @@ sig_fit <- function(catalogue_matrix,
                     sig_db = c(
                       "legacy", "SBS", "DBS", "ID", "TSB",
                       "SBS_Nik_lab", "RS_Nik_lab",
-                      "RS_BRCA560", "RS_USARC", "CNS_USARC", "CNS_TCGA",
+                      "RS_BRCA560", "RS_USARC",
+                      "CNS_USARC", "CNS_TCGA",
+                      "CNS_TCGA176","CNS_PCAWG176",
                       "SBS_hg19", "SBS_hg38", "SBS_mm9", "SBS_mm10",
                       "DBS_hg19", "DBS_hg38", "DBS_mm9", "DBS_mm10",
                       "SBS_Nik_lab_Organ", "RS_Nik_lab_Organ",
